/*
 * Copyright (C) the libgit2 contributors. All rights reserved.
 *
 * This file is part of libgit2, distributed under the GNU GPL v2 with
 * a Linking Exception. For full terms see the included COPYING file.
 */

#ifndef INCLUDE_experimental_h__
#define INCLUDE_experimental_h__

/* #undef GIT_EXPERIMENTAL_SHA256 */

#endif
